<?php

namespace WpieApp\Core\Office\Converter;

use WpieApp\Core\Office\Reader\CSV\Reader;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Resource\Resource;

defined( 'ABSPATH' ) || exit;

class Csv2Xml {

        
        private static $fp = null;

        
        private static $row = null;

        
        private static $reader = null;

        
        public static function convert( $source = "", $dest = "", $start = 0 ) {

                Resource::increase();
                
                self::$reader = new Reader();

                $isLoaded = self::$reader->load( $source );

                if ( \is_wp_error( $isLoaded ) ) {
                        return $isLoaded;
                }

                $filePath = self::writeXml( $dest, $start );

                self::$reader = null;

                return $filePath;
        }

        
        private static function writeXml( $file = "", $start = 0 ) {

                self::$fp = Helper::fOpen( $file, 'a' );

                if ( \is_wp_error( self::$fp ) ) {
                        return self::$fp;
                }

                if ( $start === 0 ) {
                        self::addHeader();
                } else {
                        self::$reader->goToRow( $start );
                }

                $currentRow = 0;

                while ( self::$row = self::$reader->getData() ) {

                        self::addRow();

                        if ( Resource::isExceeded() ) {
                                $currentRow = self::$reader->getRowNumber();
                                break;
                        }
                }

                if ( $currentRow > 0 ) {
                        fclose( self::$fp );
                        return [ "file" => $file, "start" => $currentRow, "status" => "processing" ];
                }

                self::addFooter();

                fclose( self::$fp );

                return [ "file" => $file, "status" => "completed" ];
        }

        
        private static function addRow() {

                $xml = "";

                $xml .= self::addTag( "item", "open" );

                foreach ( self::$row as $tag => $content ) {

                        $data = self::sanitizeData( $content );

                        if ( Helper::isEmpty( $data ) ) {
                                $xml .= self::addTag( $tag, "selfclose" );
                                continue;
                        }
                        $xml .= self::addTag( $tag, "open" );
                        $xml .= $data;
                        $xml .= self::addTag( $tag, "close" );
                }

                $xml .= self::addTag( "item", "close" );

                fwrite( self::$fp, $xml );

                unset( $xml );
        }

        
        private static function addTag( $tag, $type = "open" ) {

                $close     = ($type === "close" ? '/' : '');
                $selfclose = ($type === "selfclose" ? '/' : '');

                return '<' . $close . Helper::sanitizeKey( $tag ) . $selfclose . '>';
        }

        
        private static function sanitizeData( $data = "" ) {

                if ( !Helper::isNonEmptyStr( $data ) ) {
                        return $data;
                }

                $data = Helper::toUtf8( $data );

                return '<![CDATA[' . str_replace( ']]>', ']]]]><![CDATA[>', $data ) . ']]>';
        }

        
        private static function addHeader() {

                $xml = '<?xml version="1.0" encoding="UTF-8" ?>';
                $xml .= self::addTag( "wpie_data", "open" );
                fwrite( self::$fp, $xml );
        }

        
        private static function addFooter() {

                $xml = self::addTag( "wpie_data", "close" );

                fwrite( self::$fp, $xml );
        }

}
