<?php

namespace WpieApp\Core\Office\Converter;

use WP_Error;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Resource\Resource;

defined( 'ABSPATH' ) || exit;


class Json2Xml {

        
        private static $data = null;

        
        private static $fp = null;

        
        public static function convert( $source = "", $dest = "" ) {

                Resource::increase();

                $isValid = self::setJson( $source );

                if ( is_wp_error( $isValid ) ) {
                        return $isValid;
                }

                return self::generateXml( $dest );
        }

        
        private static function setJson( $source = "" ) {

                if ( !Helper::isNonEmptyStr( $source ) || !Helper::getFilesystem()->exists($source ) ) {

                        return new WP_Error( 'wpie_import_error', __( 'Json File Not Exist', 'wp-import-export' ) );
                }

                if ( filesize( $source ) === 0 ) {

                        return new WP_Error( 'wpie_import_error', __( 'Json File is Empty', 'wp-import-export' ) );
                }

                self::$data = Helper::jsonDecode( Helper::getFilesystem()->get_contents(  $source ), true );

                if ( self::$data === false || !Helper::isNonEmptyArray( self::$data ) ) {
                        return new WP_Error( 'wpie_import_error', __( 'Invalid Json File', 'wp-import-export' ) );
                }

                return true;
        }

        
        private static function generateXml( $file = "" ) {

                self::$fp = Helper::fOpen( $file, 'a' );

                if ( \is_wp_error( self::$fp ) ) {
                        return self::$fp;
                }

                self::addHeader();

                self::generate( "", self::$data );

                self::addFooter();

                fclose( self::$fp );

                return [ "file" => $file, "status" => "completed" ];
        }

        
        private static function generate( $tag = "", $data = [] ) {

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return;
                }

                if ( self::isArrayAllKeySequential( $data ) ) {

                        $tag = Helper::isNonEmptyStr( $tag ) ? $tag : 'item';

                        foreach ( $data as $k => $v ) {
                                self::addTag( $tag, $v );
                        }
                        return;
                }

                foreach ( $data as $newTag => $content ) {

                        if ( self::isArrayAllKeySequential( $content ) ) {

                                foreach ( $content as $k => $v ) {
                                        self::addTag( ( string ) $newTag, $v );
                                }
                                continue;
                        }

                        self::addTag( $newTag, $content );
                }

                return;
        }

        
        private static function addTag( $tag = "", $content = "" ) {

                self::addData( self::getTag( $tag, "open" ) );

                if ( is_array( $content ) ) {
                        self::generate( $tag, $content );
                } else {
                        self::addData( self::sanitizeData( $content ) );
                }

                self::addData( self::getTag( $tag, "close" ) );
        }

        
        private static function getTag( $tag, $type = "open" ) {

                $close     = ($type === "close" ? '/' : '');
                $selfclose = ($type === "selfclose" ? '/' : '');

                return '<' . $close . Helper::sanitizeKey( $tag ) . $selfclose . '>';
        }

        
        private static function sanitizeData( $data = "" ) {

                if ( !Helper::isNonEmptyStr( $data ) || is_numeric( $data ) ) {
                        return $data;
                }

                return '<![CDATA[' . str_replace( ']]>', ']]]]><![CDATA[>', Helper::toUtf8( $data ) ) . ']]>';
        }

        
        private static function addHeader() {

                $xml = '<?xml version="1.0" encoding="UTF-8" ?>';
                $xml .= self::getTag( "wpie_data", "open" );
                self::addData( $xml );
        }

        
        private static function addFooter() {

                self::addData( self::getTag( "wpie_data", "close" ) );
        }

        
        private static function addData( $data ) {
                fwrite( self::$fp, $data );
        }

        
        private static function isArrayAllKeySequential( $value ) {

                if ( !is_array( $value ) ) {
                        return false;
                }

                if ( count( $value ) <= 0 ) {
                        return true;
                }

                return array_unique( array_map( 'is_int', array_keys( $value ) ) ) === [ true ];
        }

}
