<?php



namespace WpieApp\Core\Office\Writer\XML;

use WP_Error;
use DOMDocument;
use DOMElement;
use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Writer {

	
	protected DOMDocument $document;

	
	protected string $numericTagNamePrefix = 'item_';

	
	public function process( array $array = [], string $rootElement = '' ) {

		if ( !Helper::isNonEmptyStr( $rootElement ) ) {
			return new WP_Error( 'wpieError', __( "Invalid Xml Root", 'wp-import-export' ) );
		}
		
		if ( !Helper::isNonEmptyArray( $array ) ) {
			return new WP_Error( 'wpieError', __( "Invalid Input to convert xml", 'wp-import-export' ) );
		}

		$this->document = new DOMDocument( '1.0', 'UTF-8' );

		$root = $this->createRootElement( $rootElement );

		$this->document->appendChild( $root );

		$this->convertElement( $root, $array );

		$this->save();
	}

	public static function convert( array $array = [], string $rootElement = '' ) {

		$converter = new static();

		return $converter->process( $array, $rootElement );
	}


	private function convertElement( DOMElement $element, mixed $value ) {
		
		$sequential = $this->isArrayAllKeySequential( $value );

		if ( !is_array( $value ) ) {
			
			$value = htmlspecialchars( $value ?? '' );

			$value = $this->removeControlCharacters( $value );

			$element->nodeValue = $value;

			return;
		}

		foreach ( $value as $key => $data ) {
			if ( !$sequential ) {
				$element->appendChild( $this->document->createCDATASection( $data ) );
			} elseif ( is_array( $data ) ) {
				$this->addCollectionNode( $element, $data );
			} else {
				$this->addSequentialNode( $element, $data );
			}
		}
	}

	protected function addNumericNode( DOMElement $element, mixed $value ): void {
		foreach ( $value as $key => $item ) {
			$this->convertElement( $element, [ $this->numericTagNamePrefix . $key => $item ] );
		}
	}

	protected function addNode( DOMElement $element, string $key, mixed $value ): void {
		if ( $this->replaceSpacesByUnderScoresInKeyNames ) {
			$key = str_replace( ' ', '_', $key );
		}

		$child = $this->document->createElement( $key );
		$element->appendChild( $child );
		$this->convertElement( $child, $value );
	}

	protected function addCollectionNode( DOMElement $element, mixed $value ): void {
		if ( $element->childNodes->length === 0 && $element->attributes->length === 0 ) {
			$this->convertElement( $element, $value );

			return;
		}

		$child = $this->document->createElement( $element->tagName );
		$element->parentNode->appendChild( $child );
		$this->convertElement( $child, $value );
	}

	protected function addSequentialNode( DOMElement $element, mixed $value ): void {
		if ( empty( $element->nodeValue ) && !is_numeric( $element->nodeValue ) ) {
			$element->nodeValue = htmlspecialchars( $value );

			return;
		}

		$child			 = $this->document->createElement( $element->tagName );
		$child->nodeValue	 = htmlspecialchars( $value );
		$element->parentNode->appendChild( $child );
	}

	protected function isArrayAllKeySequential( $value ) {
		if ( !is_array( $value ) ) {
			return false;
		}

		if ( count( $value ) <= 0 ) {
			return true;
		}

		if ( \key( $value ) === '__numeric' ) {
			return false;
		}

		return array_unique( array_map( 'is_int', array_keys( $value ) ) ) === [ true ];
	}

}
