<?php


namespace WpieApp\Core\Page\Blocks\Fields;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Date;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Page\Blocks\Fields\Alert;

defined( 'WPIE__FILE__' ) || exit;


class ScheduleImport {

        
        const TYPE = "schedule-import";

        
        public static function render( $field ) {

                $templates = DB::wpdb()->get_results( "SELECT `id`,`content_type`,`category`,`process_type`,`options`,`status`,`name`,`file` FROM " . DB::getPluginTable() . " where `process` = 'import' AND `process_type` = 'schedule' AND `status` != 'draft' ORDER BY `id` DESC", ARRAY_A );

                $emptyClass = Helper::isNonEmptyArray( $templates ) ? "d-none" : "";
                ?>
                <div class="wpie-log-wrapper">
                        <div class="wpie-log-empty-wrapper  <?php echo esc_attr( $emptyClass ); ?>">
                                <div class="text-center m-auto py-4 bse-fw-600 bse-text-18"><?php esc_html_e( 'No records found', 'wp-import-export' ); ?></div>
                        </div>

                        <?php
                        if ( Helper::isNonEmptyArray( $templates ) ) {
                                self::renderData( $templates );
                        }
                        ?>
                </div>

                <?php
        }

        
        private static function renderData( $templates ) {
                ?>

                <div class="wpie-import-log-wrapper wpie-log-container container bse-fs-12">
                        <div class="col-12 bse-fs-14">
                                <?php
                                Alert::render(
                                        [
                                                "type"       => "danger",
                                                "icon-class" => "fa-solid fa-triangle-exclamation",
                                                "class"      => "mb-4",
                                                "text"       => __( 'If the cron job is not running, all scheduled tasks will be skipped', 'wp-import-export' )
                                        ]
                                );
                                ?>
                        </div>
                        <div class="row py-4">
                                <div class="col-auto my-auto">
                                        <div class="wpie-field">
                                                <select class="form-control form-select wpie-select wpie-bulk-actions" data-minimum-results-for-search="Infinity" data-placeholder="<?php esc_html_e( 'Bulk Actions', 'wp-import-export' ); ?>" >
                                                        <option></option>
                                                        <option value="remove"><?php esc_html_e( 'Remove Selected', 'wp-import-export' ); ?></option>
                                                </select>
                                        </div>
                                </div>
                                <div class="col-auto my-auto">
                                        <div class="wpie-field">
                                                <button type="button" class="btn wpie-bulk-action-btn btn-primary"><i class="bse-fs-14 me-1 fa-solid fa-check"></i><?php esc_html_e( 'Apply', 'wp-import-export' ); ?></button>
                                        </div>
                                </div>
                        </div>
                        <div class="row py-4 bse-fw-600">
                                <div class="col-auto m-auto">
                                        <div class="form-check ">
                                                <input type="checkbox" class="form-check-input form-checkbox wpie-check-all" value="" />
                                        </div>
                                </div>
                                <div class="col m-auto"><?php esc_html_e( 'Name', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Content Type', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Date', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Summary', 'wp-import-export' ); ?></div>

                        </div>
                        <?php
                        $schedules = \wp_get_schedules();

                        foreach ( $templates as $data ) {

                                $id = isset( $data[ 'id' ] ) ? absint( $data[ 'id' ] ) : "";

                                $nextRunTime = \wp_next_scheduled( 'WpieApp/Schedule/Start', [ $id ] );

                                $name           = isset( $data[ 'name' ] ) ? $data[ 'name' ] : "";
                                $file           = isset( $data[ 'file' ] ) ? $data[ 'file' ] : "";
                                $options        = isset( $data[ 'options' ] ) && Helper::isNonEmptyStr( $data[ 'options' ] ) ? \maybe_unserialize( $data[ 'options' ] ) : [];
                                $schedule       = isset( $options[ 'schedule' ] ) ? $options[ 'schedule' ] : [];
                                $firstRun       = isset( $schedule[ 'first-run' ] ) ? Date::getLocal( $schedule[ 'first-run' ] ) : "-";
                                $lastRun        = isset( $schedule[ 'last-run' ] ) ? Date::getLocal( $schedule[ 'last-run' ] ) : "-";
                                $recurrences    = isset( $schedule[ 'recurrences' ] ) ? Helper::toInt( $schedule[ 'recurrences' ] ) : "0";
                                $skipped        = isset( $schedule[ 'skipped' ] ) ? Helper::toInt( $schedule[ 'skipped' ] ) : "0";
                                $failed         = isset( $schedule[ 'failed' ] ) ? Helper::toInt( $schedule[ 'failed' ] ) : "0";
                                $interval       = isset( $schedule[ 'interval' ] ) ? $schedule[ 'interval' ] : "";
                                $recurrenceTime = isset( $schedules[ $interval ] ) && isset( $schedules[ $interval ][ 'display' ] ) ? $schedules[ $interval ][ 'display' ] : $interval;
                                $category       = isset( $data[ 'category' ] ) ? $data[ 'category' ] : "";
                                $contentType    = isset( $data[ 'content_type' ] ) ? $data[ 'content_type' ] : "";
                                $status         = isset( $data[ 'status' ] ) ? $data[ 'status' ] : "";

                                $nextRun = (($nextRunTime === false || $status === 'paused') ? "-" : Date::getLocalByTimestamp( $nextRunTime ));

                                $contentTypeLabel = (isset( $options[ 'Info' ] ) && isset( $options[ 'Info' ][ 'Content' ] ) && isset( $options[ 'Info' ][ 'Content' ][ 'Label' ] ) ? $options[ 'Info' ][ 'Content' ][ 'Label' ] : '');
                                $error            = "";

                                if ( in_array( $status, [ 'failed', 'stopped', 'error' ] ) ) {
                                        $options = isset( $data[ 'options' ] ) && Helper::isNonEmptyStr( $data[ 'options' ] ) ? \maybe_unserialize( $data[ 'options' ] ) : [];
                                        $error   = isset( $options[ 'error' ] ) ? $options[ 'error' ] : "";
                                }

                                $timeString = ($nextRunTime === false ) ? '' : __( 'In', 'wp-import-export' ) . ' ' . \human_time_diff( time(), $nextRunTime );
                                if ( $nextRunTime === false ) {
                                        $status = 'failed';
                                        $error  = __( 'The event that was scheduled is missing', 'wp-import-export' );
                                }
                                if ( $status !== 'paused' && time() >= $nextRunTime ) {
                                        $timeString = '';
                                        $nextRun    = __( 'Processing... Kindly refresh', 'wp-import-export' );
                                }
                                ?>
                                <div class="row border-top py-4 wpie-log" log-id="<?php echo esc_attr( $id ); ?>">
                                        <div class="col-auto m-auto">
                                                <div class="form-check ">
                                                        <input type="checkbox" class="form-check-input form-checkbox wpie-check wpie-export-log-ids" value="<?php echo esc_attr( $id ); ?>" />
                                                </div>
                                        </div>
                                        <div class="col m-auto">
                                                <div class="mb-3 bse-fw-600 text-primary"><?php echo \esc_html( $name ); ?></div>
                                                <div class="mb-3 bse-fw-600 text-success"><?php echo \esc_html( $file ); ?></div>
                                                <div class="bse-fs-24 mt-2">
                                                        <i class="fa-solid fa-trash text-danger me-3 bse-cursor-pointer wpie-remove-schedule-btn" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Remove Schedule', 'wp-import-export' ); ?>"></i>
                                                        <i class="fa-solid fa-circle-play me-3 text-success bse-cursor-pointer wpie-resume-schedule <?php echo ($status === "paused") ? "" : esc_attr( "d-none" ); ?>" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Resume Schedule', 'wp-import-export' ); ?>"></i>
                                                        <i class="fa-solid fa-circle-pause me-3 text-primary bse-cursor-pointer wpie-pause-schedule <?php echo!in_array( $status, [ 'failed', 'stopped', 'error', 'paused' ] ) ? "" : esc_attr( "d-none" ); ?>" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Pause Schedule', 'wp-import-export' ); ?>"></i>
                                                        <?php if ( $nextRunTime === false ) { ?>
                                                                <i class="fa-solid fa-screwdriver-wrench me-3 text-success bse-cursor-pointer wpie-fix-schedule" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Fix the schedule', 'wp-import-export' ); ?>"></i>
                                                        <?php } ?>
                                                        <i class="fa-solid fa-file-lines text-secondary bse-cursor-pointer me-3 wpie-download-process-log" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Download Log', 'wp-import-export' ); ?>"></i>
                                                </div>
                                        </div>
                                        <div class="col m-auto">
                                                <?php if ( Helper::isNonEmptyStr( $contentTypeLabel ) ) { ?>
                                                        <div class="text-primary bse-fw-600"><?php echo esc_html( $contentTypeLabel ); ?></div> 
                                                <?php } ?>
                                                <div class="text-success"><?php echo esc_html( $category . " => " . $contentType ); ?></div>
                                        </div>
                                        <div class="col m-auto">
                                                <div><?php esc_html_e( 'First Run', 'wp-import-export' ); ?></div>
                                                <div class="text-success"><?php echo esc_html( $firstRun ); ?></div>
                                                <div class="mt-3"><?php esc_html_e( 'Last Run', 'wp-import-export' ); ?></div>
                                                <div class="text-success"><?php echo esc_html( $lastRun ); ?></div>
                                                <div class="mt-3"><?php esc_html_e( 'Next Run', 'wp-import-export' ); ?></div>
                                                <div class="text-primary wpie-schedule-next-run wpie-schedule-next-run-time bse-fw-600 <?php echo ($status === "paused") ? esc_attr( "d-none" ) : ''; ?>"><?php echo esc_html( $timeString ); ?></div>
                                                <div class="text-success wpie-schedule-next-run wpie-schedule-next-run-date"><?php echo esc_html( $nextRun ); ?></div>
                                        </div>
                                        <div class="col m-auto wpie-actions">
                                                <div class="wpie-schedule-status mb-3 <?php echo ( $status === 'paused' ) ? "" : esc_attr( "d-none" ); ?>"><?php esc_html_e( 'Status', 'wp-import-export' ); ?> : <strong class="text-danger"><?php esc_html_e( 'Paused', 'wp-import-export' ); ?></strong></div>
                                                <div><?php esc_html_e( 'Recurrence Time', 'wp-import-export' ); ?></div>
                                                <div class="mb-3 bse-fw-600"><?php echo esc_html( $recurrenceTime ); ?></div>
                                                <div class="mb-3"><?php esc_html_e( 'Recurrences', 'wp-import-export' ); ?> : <strong class="text-success"><?php echo esc_html( $recurrences ); ?></strong></div>
                                                <div class="mb-3"><?php esc_html_e( 'Processed', 'wp-import-export' ); ?> : <strong class="text-success"><?php echo esc_html( $recurrences - $skipped ); ?></strong></div>
                                                <?php if ( $skipped > 0 ) { ?>
                                                        <div class="mb-3"><?php esc_html_e( 'Skipped', 'wp-import-export' ); ?> : <strong class="text-danger"><?php echo esc_html( $skipped ); ?></strong></div>
                                                <?php } ?>
                                                <?php if ( $failed > 0 ) { ?>
                                                        <div class="mb-3"><?php esc_html_e( 'Failed', 'wp-import-export' ); ?> : <strong class="text-danger"><?php echo esc_html( $failed ); ?></strong></div>
                                                <?php } ?>
                                        </div>
                                        <?php if ( Helper::isNonEmptyStr( $error ) ) { ?>
                                                <div class="col-12 mt-3 text-danger bse-fs-12 mb-3 wpie-error-msg"><span class="bse-fw-600 bse-fs-14"><?php $status === "stopped" ? esc_html_e( 'Note', 'wp-import-export' ) : esc_html_e( 'Error', 'wp-import-export' ); ?> : </span><?php echo esc_html( $error ); ?></div>
                                        <?php } ?>
                                </div>
                                <?php
                        }
                        ?>

                </div>

                <?php
        }
}
