<?php



namespace WpieApp\Extensions\Export\Acf\Controller\Items\Base\DataCenters;

use WpieApp\Core\Utils\User;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Extensions\Export\Acf\Controller\Items\Base\DataCenters\Relational\AdvancedLink;

defined( 'WPIE__FILE__' ) || exit;


class RelationalField {

        
        public static function isValidField( $type = "" ) {
                return in_array( $type, [ 'acfe_advanced_link', 'page_link', 'post_object', 'relationship', 'taxonomy', 'acfe_taxonomy_terms', 'user' ] );
        }

        
        public static function getData( $type = '', $data = [], $key = '', $fieldId = '' ) {

                switch ( $type ) {

                        case 'acfe_advanced_link':
                                $data = AdvancedLink::getData( $data, $key, $fieldId );

                                break;
                        case 'page_link':
                                // get field
                              //  $field = \acf_maybe_get_field( $key, $fieldId );
                                $data  = self::getPost( $data, true );

                                break;

                        case 'post_object':
                        case 'relationship':
                                $data = self::getPost( $data );
                                break;

                        case 'taxonomy':
                        case 'acfe_taxonomy_terms':
                                $data = self::getTerm( $data );
                                break;

                        case 'user':
                                $data = self::getUser( $data );
                                break;
                }

                return $data;
        }

        
        public static function getPost( $data = [], $link = false ) {

                if ( is_numeric( $data ) ) {
                        $data = [ $data ];
                }
                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return '';
                }

                $postData = [];

                foreach ( $data as $id ) {
                        $post = [
                                'title'     => \get_post_field( 'post_title', $id ),
                                'slug'      => \get_post_field( 'post_name', $id ),
                                'post_type' => \get_post_type( $id ),
                        ];
                        if ( $link ) {
                                $post[ 'link' ] = \get_the_permalink( $id );
                        }
                        $postData[] = $post;
                }

                return $postData;
        }

        
        public static function getTerm( $data = [] ) {

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return '';
                }

                $termData = [];

                foreach ( $data as $id ) {

                        $term = \get_term( $id );

                        if ( is_null( $term ) || is_wp_error( $term ) || !isset( $term->name ) ) {
                                continue;
                        }

                        $termData[] = [
                                'name'     => isset( $term->name ) ? $term->name : '',
                                'taxonomy' => isset( $term->taxonomy ) ? $term->taxonomy : '',
                                'slug'     => isset( $term->slug ) ? $term->slug : '',
                        ];
                }

                return $termData;
        }

        
        public static function getUser( $data = [] ) {

                if ( is_numeric( $data ) ) {
                        $data = [ $data ];
                }

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return '';
                }

                $users = [];

                foreach ( $data as $id ) {

                        $users[] = User::getEmail( $id );
                }

                return $users;
        }
}
