<?php



namespace WpieApp\Extensions\Export\AllInOneSeo\Controller\Items\Taxonomy\DataCenters;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Taxonomy\DataCenter;
use WpieApp\Core\Logger\Logger;

defined( 'WPIE__FILE__' ) || exit;


class Seo {

        
        private static $data = [];

        
        public static function getField() {

                $element = DataCenter::getFieldOption( "element" );

                if ( Helper::isEmptyStr( $element ) ) {
                        return "";
                }

                $termData = self::getData();

                $data = is_object( $termData ) && isset( $termData->$element ) ? $termData->$element : "";

                if ( Helper::isEmpty( $data ) ) {
                        return "";
                }

                if ( in_array( $element, [ 'keywords', 'og_article_tags' ] ) ) {
                        $data = self::jsonTagsToCommaSeparatedList( $data );
                }

                return $data;
        }

        
        public static function getData() {

                $termId = DataCenter::getId();

                if ( !isset( self::$data[ $termId ] ) ) {

                        self::$data = [ $termId => self::getSeoData( $termId ) ];
                }

                return self::$data[ $termId ];
        }

        
        public static function getSeoData( $termId = 0 ) {

                $data = DB::wpdb()->get_row( DB::wpdb()->prepare( "select * from " . DB::table( 'aioseo_terms' ) . " Where `term_id` = %d ", $termId ) );

                if ( Helper::isEmpty( $data ) ) {
                        return new \stdClass();
                }

                return $data;
        }

        
        public static function jsonTagsToCommaSeparatedList( $tags = '' ) {

                $tags = Helper::isNonEmptyStr( $tags ) ? Helper::jsonDecode( $tags, true ) : $tags;

                if ( \is_wp_error( $tags ) ) {

                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $tags->get_error_message() );

                        return '';
                }

                if ( !Helper::isNonEmptyArray( $tags ) ) {
                        return '';
                }

                $data = \wp_list_pluck( $tags, 'value' );

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return '';
                }

                return Helper::arrTostr( $data );
        }
}
