<?php



namespace WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Legacy\Fields;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use Automattic\WooCommerce\Internal\DataStores\Orders\OrdersTableDataStore;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\InterfaceField;
use WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Fields\Meta as BaseMeta;

defined( 'WPIE__FILE__' ) || exit;


class Meta extends BaseMeta implements InterfaceField {

        
        protected static function getMetaKeys() {

                
                $limit = \apply_filters( 'Wpie/Export/Order/Fields/Meta/Limit', 500 );

                $limit = is_numeric( $limit ) ? DB::wpdb()->prepare( '%d', $limit ) : 500;

                $excludes = static::getExcludesMetaQuery();

                $keys = DB::wpdb()->get_col(
                        "SELECT DISTINCT `postmeta`.`meta_key`
				FROM " . DB::wpdb()->postmeta . " AS `postmeta`
				LEFT JOIN " . DB::wpdb()->posts . " AS `posts` ON ( `posts`.`ID` = `postmeta`.`post_id` )
				WHERE `posts`.`post_type` = 'shop_order'
                                        $excludes
                                ORDER BY `postmeta`.`post_id` ASC
				LIMIT " . $limit
                );

                return $keys;
        }

        
        protected static function getExcludesMeta() {

                $excludes = self::getOrderMetas();

                
                $excludes = apply_filters( 'Wpie/Export/Order/Fields/Meta/Excludes', $excludes );

                return Helper::isNonEmptyArray( $excludes ) ? array_unique( $excludes ) : [];
        }

        
        protected static function getExcludesMetaQuery() {

                $query = [
                        " AND `posts`.`post_status` NOT IN ( 'trash' , 'auto-draft' ) ",
                        " AND `postmeta`.`meta_key` NOT LIKE '_edit%' ",
                        " AND `postmeta`.`meta_key` NOT LIKE '_oembed_%' ",
                        " AND `postmeta`.`meta_value` != '' ",
                ];

                $keys = DB::prepareData( static::getExcludesMeta() );

                if ( Helper::isNonEmptyStr( $keys ) ) {
                        $query[] = " AND `postmeta`.`meta_key` NOT IN ( " . $keys . " ) ";
                }

                
                $query = \apply_filters( 'Wpie/Export/Order/Fields/Meta/Query/Where', $query );

                return Helper::isNonEmptyArray( $query ) ? implode( " ", array_unique( $query ) ) : "";
        }

        
        public static function getOrderMetas() {

                return [
                        //Customer User
                        '_customer_user',
                        //
                        //Billing Fields
                        '_billing_first_name', '_billing_last_name', '_billing_company',
                        '_billing_address_1', '_billing_address_2', '_billing_city',
                        '_billing_postcode', '_billing_country', '_billing_state',
                        '_billing_email', '_billing_phone',
                        //
                        //Shipping Fields
                        '_shipping_first_name', '_shipping_last_name', '_shipping_company',
                        '_shipping_address_1', '_shipping_address_2', '_shipping_city',
                        '_shipping_postcode', '_shipping_country', '_shipping_state',
                        '_shipping_phone',
                        //                                             
                        //order
                        "_order_tax", "_order_shipping", "_cart_discount",
                        "_order_key", "_completed_date", "_date_completed", "_date_paid", "_paid_date", "_order_currency", "_payment_method_title", "_order_total", "_prices_include_tax",
                        "_customer_ip_address", "_customer_user_agent", "_created_via", "_order_version", "_payment_method", "_cart_discount_tax",
                        "_order_shipping_tax", "_recorded_sales", "_order_stock_reduced", "_recorded_coupon_usage_counts", "_transaction_id", "_cart_hash",
                        //
                        //Refund Meta
                        "_refund_amount", "_refunded_by", "_refunded_payment", "_refund_reason"
                ];
        }
}
