<?php



namespace WpieApp\Extensions\Export\WooCommerce\Controller;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class WcTypes {

        
        public static function init() {

                \add_filter( 'Wpie/Modules/Export/View/ContentType', [ __CLASS__, 'addWcTypes' ] );

                \add_filter( 'Wpie/ImpExpTypes', [ __CLASS__, 'getContentTypes' ] );

                \add_filter( 'Wpie/ImpExpTypes/Posts/Excludes', [ __CLASS__, 'excludePosts' ] );

                \add_filter( 'Wpie/ImpExpTypes/Taxonomy/Excludes', [ __CLASS__, 'excludeTaxonomy' ] );
        }

        
        public static function excludeTaxonomy( $taxonomies = [] ) {

                return array_merge( $taxonomies, [ 'product_cat', 'product_tag' ] );
        }

        
        public static function excludePosts( $posts = [] ) {

                return array_merge( $posts, [ 'product', 'shop_order', 'shop_coupon', 'product_variation', 'shop_order_refund', 'shop_order_placehold' ] );
        }

        
        public static function getContentTypes( $contentTypes = [] ) {

                return array_replace( $contentTypes, self::getWcTypes() );
        }

        
        public static function getWcTypes() {

                return [
                        'wc/product'         => __( 'Products', 'wp-import-export' ),
                        'wc/product_cat'     => __( 'Product Categories', 'wp-import-export' ),
                        'wc/product_tag'     => __( 'Product Tags', 'wp-import-export' ),
                        'wc/product_reviews' => __( 'Product Reviews', 'wp-import-export' ),
                        'wc/attribute'       => __( 'Product Attributes', 'wp-import-export' ),
                        'wc/shop_order'      => __( 'Shop Orders', 'wp-import-export' ),
                        'wc/shop_customer'   => __( 'Customers', 'wp-import-export' ),
                        'wc/shop_coupon'     => __( 'Coupons', 'wp-import-export' ),
                ];
        }

        
        public static function addWcTypes( $data = [] ) {

                $data = Helper::isNonEmptyArray( $data ) ? $data : [];

                $data[ 'fields' ] = isset( $data[ 'fields' ] ) && Helper::isNonEmptyArray( $data[ 'fields' ] ) ? $data[ 'fields' ] : [];

                $data[ 'fields' ][ 'woocommerce' ] = [
                        "order"       => 15,
                        "wrapper-col" => "col-lg-6",
                        "label"       => __( 'WooCommerce', 'wp-import-export' ),
                        "sub-fields"  => [
                                "post" => [
                                        "pro-backdrop" => WPIE_PRO ? false : true,
                                        "col-class"    => "cols",
                                        "type"         => "radio",
                                        "order"        => 5,
                                        "name"         => "content_type",
                                        "class"        => "wpie-content-type",
                                        "default"      => "",
                                        "description"  => __( 'WooCommerce Shop Data', 'wp-import-export' ),
                                        "choices"      => self::getWcTypes()
                                ],
                        ],
                ];

                return $data;
        }
}
