<?php



namespace WpieApp\Extensions\Import\Acf\Controller\Items\Base\Engines;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Base\DataCenter;
use WpieApp\Modules\Import\Controller\Items\Base\Engines\Images\Source;
use WpieApp\Modules\Import\Controller\Items\Base\Engines\Images\Attachment;
use WpieApp\Modules\Import\Controller\Items\Base\Engines\Images\Gallery;

defined( 'WPIE__FILE__' ) || exit;


class Content extends Base {

        
        protected static $fieldTypes = [ 'acfe_code_editor', 'file', 'font-awesome', 'gallery', 'image', 'image_aspect_ratio_crop', 'photo_gallery', 'wysiwyg', 'oembed' ];

        
        public static function getData() {

//                if ( in_array( static::$fieldType, [ 'acfe_code_editor', 'wysiwyg', 'oembed' ] ) ) {
//                        return parent::getData();
//                }

                switch ( static::$fieldType ) {

                        case 'font-awesome':
                                static::$data = static::getFont();
                                break;

                        case 'image':
                        case 'image_aspect_ratio_crop':
                                static::$data = static::getImage();
                                break;

                        case 'gallery':
                                static::$data = static::getGallery();
                                break;

                        case 'photo_gallery':
                                $data         = static::getGallery();
                                static::$data = Helper::isNonEmptyArray( $data ) ? Helper::arrTostr( $data ) : '';
                                break;

                        case 'file':
                                $data         = static::getFile();
                                static::$data = (!isset( static::$field[ 'multiple' ] ) || \absint( static::$field[ 'multiple' ] ) !== 1) ? array_shift( $data ) : $data;
                                break;
                }



                return parent::getData();
        }

        
        public static function getFile() {

                $fileData = [];

                $existing = parent::getExisting();

                $existing = is_array( $existing ) ? $existing : [ $existing ];

                $files = Helper::strToArr( static::$data );

                foreach ( $files as $file ) {

                        $existingFound = false;

                        foreach ( $existing as $existingFile ) {

                                $file = static::findFile( $file, $existingFile );

                                if ( is_numeric( $file ) && $file > 0 ) {
                                        $existingFound = true;
                                        $fileData[]    = $file;
                                        break;
                                }
                        }

                        if ( $existingFound ) {
                                continue;
                        }

                        $fileData[] = static::downloadFile( $file );
                }

                return $fileData;
        }

        
        public static function getFont() {

                $fontData = Helper::jsonDecode( static::$data, true );

                if ( !Helper::isNonEmptyArray( $fontData ) || !isset( $fontData[ 'id' ] ) ) {

                        return '';
                }

                return static::$data;
        }

        
        public static function findFile( $sourceFle = '', $existing = 0 ) {

                if ( is_numeric( $existing ) ) {

                        $file = \get_attached_file( $existing );

                        if ( false !== $file && basename( $file ) === basename( Helper::sanitizeFilename( $sourceFle ) ) ) {
                                return $existing;
                        }
                }

                $id = Attachment::search( $sourceFle );

                if ( is_numeric( $id ) && $id > 0 ) {
                        return $id;
                }

                return 0;
        }

        
        public static function downloadFile( $image = '' ) {
                return Source::upload( $image );
        }

        
        public static function getGallery() {

                $separator = DataCenter::get( 'acf/' . static::$key . '/separator' );

                $data = Helper::strToArr( static::$data, Helper::isNonEmptyStr( $separator ) ? $separator : '||' );

                $existing = parent::getExisting();

                $gallery = [];

                foreach ( $data as $source ) {

                        $image = static::findImage( $source, $existing );

                        if ( is_numeric( $image ) && $image > 0 ) {

                                $gallery[] = $image;
                                continue;
                        }

                        $gallery[] = static::downloadImage( $source );
                }

                return $gallery;
        }

        
        public static function getImage() {

                $existing = parent::getExisting();

                $image = static::findImage( static::$data, [ $existing ] );

                if ( is_numeric( $image ) && $image > 0 ) {

                        return $image;
                }

                return static::downloadImage( static::$data );
        }

        
        public static function findImage( $image = '', $existing = [] ) {

                if ( Helper::isNonEmptyArray( $existing ) ) {

                        $id = 0;

                        foreach ( $existing as $atach ) {

                                $file = \get_attached_file( $atach );

                                if ( false !== $file && basename( $file ) === basename( Helper::sanitizeFilename( $image ) ) ) {
                                        $id = $atach;
                                        break;
                                }
                        }

                        if ( $id > 0 ) {
                                return $id;
                        }
                }

                $id = Gallery::search( $image );

                if ( is_numeric( $id ) && $id > 0 ) {
                        return $id;
                }

                return 0;
        }

        
        public static function downloadImage( $image = '' ) {
                return Source::upload( $image );
        }
}
