<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\Engines\Items;

use WC_Data_Store;
use WC_Customer_Download;
use WC_Customer_Download_Log;
use WpieApp\Core\Utils\Date;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\User\Search;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Download extends Base {

        
        private static $downloads;

        
        private static $orderId = 0;

        
        protected static function update() {

                $id = Helper::isNonEmptyArray( self::$item ) && isset( self::$item[ 'permission_id' ] ) ? self::$item[ 'permission_id' ] : 0;

                $item = new WC_Customer_Download( $id );

                if ( $id < 1 ) {

                        self::setProduct();

                        if ( isset( self::$data[ 'download-id' ] ) ) {
                                $item->set_download_id( Helper::sanitizeText( self::$data[ 'download-id' ] ) );
                        }
                        if ( isset( self::$data[ 'product-id' ] ) ) {
                                $item->set_product_id( Helper::sanitizeText( self::$data[ 'product-id' ] ) );
                        }

                        $item->set_user_id( DataCenter::getItem()->get_customer_id() );
                        $item->set_order_id( DataCenter::getItem()->get_id() );
                        $item->set_user_email( DataCenter::getItem()->get_billing_email() );
                        $item->set_order_key( DataCenter::getItem()->get_order_key() );
                }

                if ( isset( self::$data[ 'remaining' ] ) ) {
                        $item->set_downloads_remaining( Helper::sanitizeText( self::$data[ 'remaining' ] ) );
                }
                if ( isset( self::$data[ 'access-granted' ] ) ) {
                        $item->set_access_granted( Helper::sanitizeText( self::$data[ 'access-granted' ] ) );
                }
                if ( isset( self::$data[ 'access-expires' ] ) ) {
                        $item->set_access_expires( Helper::sanitizeText( self::$data[ 'access-expires' ] ) );
                }
                if ( isset( self::$data[ 'count' ] ) ) {
                        $item->set_download_count( Helper::toInt( self::$data[ 'count' ] ) );
                }

                $item->save();

                self::updateLog( $item->get_id() );

                unset( $item );
        }

        
        protected static function updateLog( $permissionId = 0 ) {


                if ( !isset( self::$data[ 'log' ] ) || !Helper::isNonEmptyArray( self::$data[ 'log' ] ) ) {
                        return;
                }

                // Check for count of download logs.
                $dataStore   = WC_Data_Store::load( 'customer-download-log' );
                $downloadLog = $dataStore->get_download_logs_for_permission( $permissionId );

                foreach ( self::$data[ 'log' ] as $log ) {

                        $timestampData = isset( $log[ 'timestamp' ] ) ? $log[ 'timestamp' ] : "";
                        $timestamp     = is_array( $timestampData ) && isset( $timestampData[ 'date' ] ) ? Date::get( Helper::sanitizeText( $timestampData[ 'date' ] ) ) : "";

                        if ( !Helper::isNonEmptyStr( $timestamp ) ) {
                                continue;
                        }

                        if ( Helper::isNonEmptyArray( $downloadLog ) ) {

                                $isExist = false;

                                foreach ( $downloadLog as $downloaddata ) {

                                        if ( $timestamp === $downloaddata->get_timestamp( 'edit' )->getTimestamp() ) {
                                                $isExist = true;
                                                break;
                                        }
                                }
                                if ( $isExist ) {
                                        continue;
                                }
                        }

                        // Track download in download log.
                        $downloadLog = new WC_Customer_Download_Log();

                        $downloadLog->set_timestamp( strtotime( $timestamp ) );

                        $downloadLog->set_permission_id( $permissionId );

                        if ( isset( $log[ 'user_email' ] ) ) {

                                $downloadLog->set_user_id( Search::getUserIdBy( 'email', Helper::sanitizeText( $log[ 'user_email' ] ) ) );
                        }

                        if ( isset( $log[ 'user_ip_address' ] ) ) {
                                $downloadLog->set_user_ip_address( Helper::sanitizeText( $log[ 'user_ip_address' ] ) );
                        }

                        $downloadLog->save();
                }
        }

        
        protected static function setItem() {

                if ( DataCenter::isNewItem() ) {
                        return;
                }

                self::setDownloads();

                $file = isset( self::$data[ 'file' ] ) ? self::$data[ 'file' ] : '';

                if ( !Helper::isNonEmptyArray( self::$downloads ) || !Helper::isNonEmptyStr( $file ) ) {
                        return;
                }

                foreach ( self::$downloads as $download ) {

                        if ( isset( $download[ 'filename' ] ) && $file === $download[ 'filename' ] ) {
                                self::$item = $download;
                                break;
                        }
                }

                unset( $file );
        }

        
        protected static function setProduct() {

                if ( count( DataCenter::getItem()->get_items() ) < 1 ) {
                        return;
                }

                $name = isset( self::$data[ 'product' ] ) ? self::$data[ 'product' ] : '';
                $file = isset( self::$data[ 'file' ] ) ? self::$data[ 'file' ] : '';

                if ( !Helper::isNonEmptyStr( $name ) || !Helper::isNonEmptyStr( $file ) ) {
                        return;
                }

                foreach ( DataCenter::getItem()->get_items() as $item ) {

                        $product = $item->get_product();

                        if ( !$product || !$product->exists() || !$product->is_downloadable() ) {
                                continue;
                        }
                        if ( $name !== $product->get_name() ) {
                                continue;
                        }

                        $downloads = $product->get_downloads();

                        if ( !Helper::isNonEmptyArray( $downloads ) ) {
                                continue;
                        }

                        foreach ( $downloads as $download ) {

                                if ( $file === $download->get_name() ) {
                                        self::$data[ 'product-id' ]  = $product->get_id();
                                        self::$data[ 'download-id' ] = $download->get_id();
                                        break 2;
                                }
                        }
                }
        }

        
        private static function setDownloads() {

                if ( self::$orderId === DataCenter::getId() ) {
                        return;
                }

                self::$orderId = DataCenter::getId();

                $downloads = [];

                $dataStore         = WC_Data_Store::load( 'customer-download' );
                $customerDownloads = $dataStore->get_downloads(
                        [
                                'order_id' => DataCenter::getItem()->get_id(),
                                'return'   => 'permission_id,download_id,product_id,downloads_remaining,access_granted,access_expires,download_count',
                        ]
                );

                unset( $dataStore );

                if ( !Helper::isNonEmptyArray( $customerDownloads ) ) {
                        return;
                }

                foreach ( $customerDownloads as $customerDownload ) {

                        $downloadId = isset( $customerDownload[ 'download_id' ] ) ? $customerDownload[ 'download_id' ] : '';

                        $productId = isset( $customerDownload[ 'product_id' ] ) ? \absint( $customerDownload[ 'product_id' ] ) : '';

                        $product = \wc_get_product( $productId );

                        if ( !$product ) {
                                continue;
                        }

                        $file = $product->get_file( $downloadId );

                        if ( false === $file ) {
                                continue;
                        }

                        $customerDownload[ 'product' ]  = $product->get_title();
                        $customerDownload[ 'filename' ] = $file->get_name();
                        $downloads[]                    = $customerDownload;
                }

                self::$downloads = $downloads;
        }
}
