<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\Engines\Items;

use WC_Data_Store;
use WC_Order_Item_Product;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\DataCenter;
use WpieApp\Modules\Import\Controller\Items\Post\Search;

defined( 'WPIE__FILE__' ) || exit;


class Product extends Base {

        
        protected static $product;

        
        public static function processItem() {

                self::$product = null;

                self::setProduct();
        }

        
        public static function update() {

                $item = new WC_Order_Item_Product( self::$item );

                if ( is_null( self::$item ) ) {
                        $item->set_order_id( DataCenter::getId() );
                }

                if ( !is_null( self::$item ) ) {
                        
                } elseif ( !is_null( self::$product ) ) {
                        $item->set_product( self::$product );
                } elseif ( isset( self::$data[ 'name' ] ) && Helper::isNonEmptyStr( self::$data[ 'name' ] ) ) {
                        $item->set_name( self::$data[ 'name' ] );
                }

                if ( isset( self::$data[ 'quantity' ] ) && is_numeric( self::$data[ 'quantity' ] ) ) {
                        $item->set_quantity( self::$data[ 'quantity' ] );
                }
                if ( isset( self::$data[ 'subtotal' ] ) && is_numeric( self::$data[ 'subtotal' ] ) ) {
                        $item->set_subtotal( self::$data[ 'subtotal' ] );
                }
                if ( isset( self::$data[ 'total' ] ) && is_numeric( self::$data[ 'total' ] ) ) {
                        $item->set_total( self::$data[ 'total' ] );
                }
                if ( isset( self::$data[ 'tax' ] ) && is_array( self::$data[ 'tax' ] ) ) {
                        $item->set_taxes( self::$data[ 'tax' ] );
                }

                $id = $item->save();

                self::setMeta( self::$data[ 'meta' ], $id );

                return $id;
        }

        
        protected static function setMeta( $metas = [], $id = 0 ) {

                if ( !Helper::isNonEmptyArray( $metas ) ) {
                        return;
                }

                foreach ( $metas as $meta ) {

                        $key = isset( $meta[ 'key' ] ) ? $meta[ 'key' ] : '';

                        if ( !Helper::isNonEmptyStr( $key ) ) {
                                return;
                        }

                        $value = isset( $meta[ 'value' ] ) ? $meta[ 'value' ] : '';

                        \wc_update_order_item_meta( $id, $key, $value );
                }
        }

        
        protected static function setItem() {

                if ( DataCenter::isNewItem() ) {
                        return;
                }

                $items = DataCenter::getItem()->get_items();

                $name = isset( self::$data[ 'item-name' ] ) ? self::$data[ 'item-name' ] : '';

                foreach ( $items as $item ) {

                        if ( $name === $item->get_name() ) {
                                self::$item    = $item;
                                self::$product = $item->get_product();
                                break;
                        }
                }
        }

        
        protected static function setItemByProduct() {

                if ( DataCenter::isNewItem() ) {
                        return;
                }
                if ( !is_null( self::$item ) || is_null( self::$product ) || !is_callable( [ self::$product, 'get_id' ] ) ) {
                        return;
                }

                $productId = self::$product->get_id();

                $variationId = self::$product->is_type( 'variable' ) ? self::$product->get_id() : 0;

                $items = DataCenter::getItem()->get_items();

                foreach ( $items as $item ) {

                        if ( $variationId > 0 ) {
                                if ( $variationId === $item->get_variation_id() ) {
                                        self::$item = $item;
                                        break;
                                }
                                continue;
                        }

                        if ( $productId === $item->get_product_id() ) {
                                self::$item = $item;
                                break;
                        }
                }
        }

        
        protected static function setProduct( $data = [] ) {

                if ( !is_null( self::$product ) ) {
                        return;
                }

                $sku = isset( $data[ 'sku' ] ) ? $data[ 'sku' ] : '';

                $id = 0;

                if ( Helper::isNonEmptyStr( $sku ) ) {
                        $id = Search::getPostIdByMeta( '_sku', $sku, [ 'product', 'product_variation' ] );
                }

                if ( $id < 1 ) {
                        $name = isset( self::$data[ 'name' ] ) ? self::$data[ 'name' ] : '';

                        $id = Helper::isNonEmptyStr( $name ) ? Search::getPostIdBy( 'title', $name, 'product' ) : 0;
                }

                if ( $id < 1 ) {
                        return;
                }

                $product = \wc_get_product( $id );

                if ( !$product ) {
                        return;
                }

                if ( $product->is_type( 'variable' ) ) {

                        $variationAttributes = isset( self::$data[ 'variation-attributes' ] ) ? self::$data[ 'variation-attributes' ] : '';

                        if ( Helper::isNonEmptyArray( $variationAttributes ) ) {

                                $data_store = WC_Data_Store::load( 'product' );

                                $variationId = $data_store->find_matching_product_variation( $product, $variationAttributes );

                                if ( $variationId > 0 ) {
                                        $product = \wc_get_product( $variationId );
                                }
                        }
                }

                self::$product = $product;
        }
}
