<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\Engines;

use WpieApp\Core\Utils\Date;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\DataCenter;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\Engines\Items\Refund as RefundItem;

defined( 'WPIE__FILE__' ) || exit;


class Refund extends ItemBase {

        
        protected static $type = 'refund';

        
        protected static function parepare() {

                self::parepareData( 'amount' );
                self::parepareData( 'reason' );
                self::parepareData( 'refund-by' );
                self::parepareData( 'date' );
                self::parepareJSONData( 'quantity' );
                self::parepareJSONData( 'items' );
                self::parepareJSONData( 'total' );
                self::parepareJSONData( 'tax' );
                self::parepareJSONData( 'fee' );
                self::parepareJSONData( 'fee-tax' );
                self::parepareJSONData( 'fee-total' );
                self::parepareJSONData( 'shipping' );
                self::parepareJSONData( 'shipping-tax' );
                self::parepareJSONData( 'shipping-total' );
        }

        
        protected static function processItem( $index = 0 ) {

                $item = [
                        'amount'       => self::getData( 'amount', $index ),
                        'reason'       => self::getData( 'reason', $index ),
                        'date_created' => self::getData( 'date', $index ),
                        'refund-by'    => self::getData( 'refund-by', $index ),
                        'line_item'    => self::getLineItems( $index ),
                        'fee'          => self::getFee( $index ),
                        'shipping'     => self::getShipping( $index )
                ];

                self::$existing[] = RefundItem::set( $item );
        }

        
        protected static function getLineItems( $index = 0 ) {

                $names    = self::getData( 'items', $index );
                $tax      = self::getData( 'tax', $index );
                $total    = self::getData( 'total', $index );
                $quantity = self::getData( 'quantity', $index );

                if ( !Helper::isNonEmptyArray( $names ) ) {
                        return [];
                }

                $data = [];

                foreach ( $names as $key => $name ) {

                        $data[] = [
                                'name'         => $name,
                                'refund_tax'   => isset( $tax[ $key ] ) && is_array( $tax[ $key ] ) ? array_map( 'abs', $tax[ $key ] ) : '',
                                'refund_total' => isset( $total[ $key ] ) ? abs( $total[ $key ] ) : '',
                                'qty'          => isset( $quantity[ $key ] ) ? abs( $quantity[ $key ] ) : '',
                        ];
                }

                return $data;
        }

        
        protected static function getShipping( $index = 0 ) {

                $shipping = self::getData( 'shipping', $index );
                $tax      = self::getData( 'shipping-tax', $index );
                $total    = self::getData( 'shipping-total', $index );

                if ( !Helper::isNonEmptyArray( $shipping ) ) {
                        return [];
                }

                $data = [];

                foreach ( $shipping as $key => $name ) {

                        $data[] = [
                                'name'         => $name,
                                'refund_tax'   => isset( $tax[ $key ] ) && is_array( $tax[ $key ] ) ? array_map( 'abs', $tax[ $key ] ) : '',
                                'refund_total' => isset( $total[ $key ] ) ? abs( $total[ $key ] ) : '',
                        ];
                }

                return $data;
        }

        
        protected static function getFee( $index = 0 ) {

                $fee   = self::getData( 'fee', $index );
                $tax   = self::getData( 'fee-tax', $index );
                $total = self::getData( 'fee-total', $index );

                if ( !Helper::isNonEmptyArray( $fee ) ) {
                        return [];
                }

                $data = [];

                foreach ( $fee as $key => $name ) {

                        $data[] = [
                                'name'         => $name,
                                'refund_tax'   => isset( $tax[ $key ] ) && is_array( $tax[ $key ] ) ? array_map( 'abs', $tax[ $key ] ) : '',
                                'refund_total' => isset( $total[ $key ] ) ? abs( $total[ $key ] ) : '',
                        ];
                }

                return $data;
        }

        
        protected static function endProcess() {

                if ( DataCenter::isNewItem() ) {
                        return;
                }

                if ( 'remove' !== DataCenter::get( static::$type . "/manage-existing/data" ) ) {
                        return;
                }

                $items = DataCenter::getItem()->get_refunds();

                if ( !Helper::isNonEmptyArray( $items ) ) {
                        return;
                }

                foreach ( $items as $item ) {

                        if ( !in_array( $item->get_id(), self::$existing ) ) {
                                DataCenter::getItem()->remove_order_refund( $item->get_id() );
                        }
                }

                // Save changes to the order
                DataCenter::getItem()->save();
        }
}
