<?php



namespace WpieApp\Modules\Export\Controller;

use WpieApp\Core\Utils\Date;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Items\Base\Logger;

defined( 'WPIE__FILE__' ) || exit;


class Schedule {

        
        public static function run( $id = 0, $action = 'new' ) {

                if ( absint( $id ) < 1 ) {
                        return;
                }

                Settings::load( $id );

                $recurrences = Settings::getOption( 'schedule/recurrences', 0 );
                $recurrences = \is_numeric( $recurrences ) ? (absint( $recurrences ) + 1) : 1;

                self::start( $recurrences );

                if ( $action === 'skip' ) {
                        Logger::log( __( 'Export in progress: the last schedule is already running', 'wp-import-export' ) );
                        Logger::log( __( 'Schedule skipped', 'wp-import-export' ) );
                        self::completed( $recurrences );
                        return self::updateLog( true );
                }

                $newId = self::add( $id, $recurrences );

                if ( absint( $newId ) > 0 ) {
                        Logger::log( __( 'New Export task successfully started', 'wp-import-export' ) );
                }

                Logger::log( __( 'The export process will start soon', 'wp-import-export' ) );

                self::completed( $recurrences );
        }

        
        public static function start( $recurrences ) {

                Logger::init();

                Logger::log( sprintf( __( "Start recurrence: %d", 'wp-import-export' ), $recurrences ) );
        }

        
        public static function completed( $recurrences ) {

                Logger::log( sprintf( __( "End recurrence: %d", 'wp-import-export' ), $recurrences ) );

                Logger::log( '.....' );
        }

        
        public static function add( $id = 0, $recurrences = 0 ) {

                if ( absint( $id ) < 1 ) {
                        return 0;
                }

                $newId = Settings::duplicate( [
                                "process"      => "export",
                                "status"       => "init",
                                "total"        => 0,
                                "process_type" => "background",
                                "name"         => "",
                                "user"         => Settings::get( "user" ),
                        ] );

                $name = Settings::get( 'name' );

                self::updateLog();

                Settings::reset();

                Settings::load( $newId );

                Settings::setOption( 'scheduleName' . $newId, $name );

                Settings::setOption( 'scheduleRecurrence' . $newId, $recurrences );

                return $newId;
        }

        
        private static function updateLog( $skip = false ) {

                $current_time = Date::now();

                $recurrences = Settings::getOption( 'schedule/recurrences', 0 );
                $recurrences = \is_numeric( $recurrences ) ? (absint( $recurrences ) + 1) : 1;

                $options = [
                        'schedule/recurrences' => $recurrences,
                        'schedule/last-run'    => $current_time
                ];

                if ( $recurrences === 1 ) {
                        $options[ 'schedule/first-run' ] = $current_time;
                }

                if ( $skip ) {
                        $skipCount                     = Settings::getOption( 'schedule/skipped', 0 );
                        $options[ 'schedule/skipped' ] = \is_numeric( $skipCount ) ? (absint( $skipCount ) + 1) : 1;
                }

                Settings::setOptions( $options );
        }

        
        public static function addLogMsg( $id = 0, $msgs = [] ) {

                Settings::load( $id );

                Logger::init();

                if ( Helper::isNonEmptyStr( $msgs ) ) {
                        $msgs = [ $msgs ];
                }

                foreach ( $msgs as $msg ) {
                        Logger::log( $msg );
                }

                Logger::log( '.....' );
        }
}
