<?php



namespace WpieApp\Modules\Export\View\Setup;

use WpieApp\Modules\Schedules\Controller\Schedule as ScheduleBase;
use WpieApp\Core\Utils\Cron;
use WpieApp\Core\Utils\Date;
use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Schedule {

        
        public static function getBlocks() {


                
                return \apply_filters(
                        'Wpie/Modules/Export/View/Schedule/Schedule',
                        [
                                "title"           => __( 'Schedule Export', 'wp-import-export' ),
                                "order"           => 40,
                                "pro-backdrop"    => WPIE_PRO ? false : true,
                                "backdrop"        => !Cron::isActive(),
                                "backdropOptions" => [
                                        'title'   => __( 'Setup Required', 'wp-import-export' ),
                                        'desc'    => __( 'Schedule Export required 2 min cron to export data. Please click on "Setup Guide" button for setup instruction.', 'wp-import-export' ),
                                        'icon'    => 'fa-solid fa-lock',
                                        'buttons' => [
                                                [
                                                        'label' => __( 'Setup Guide', 'wp-import-export' ),
                                                        'icon'  => 'fa-solid fa-lock-open',
                                                        'class' => 'btn-success',
                                                        'url'   => Helper::adminUrl( 'wpie-schedules' ),
                                                ]
                                        ]
                                ],
                                "desc"            => __( 'Add New Schedule', 'wp-import-export' ),
                                "fields"          => [
                                        "schedule-name"     => [
                                                "order"      => 10,
                                                "label"      => __( 'Schedule Name', 'wp-import-export' ),
                                                "sub-fields" => [
                                                        "name" => [
                                                                "description" => __( 'Friendly name for schedule', 'wp-import-export' ),
                                                                "name"        => "schedule/name",
                                                                "class"       => "wpie-schedule-name",
                                                                "type"        => "text",
                                                        ]
                                                ],
                                        ],
                                        "schedule-interval" => [
                                                "order"      => 20,
                                                "label"      => __( 'Schedule Interval', 'wp-import-export' ),
                                                "sub-fields" => [
                                                        "interval" => [
                                                                "type"        => "select",
                                                                "placeholder" => __( "Choose Interval", 'wp-import-export' ),
                                                                "order"       => 5,
                                                                "name"        => "schedule/interval",
                                                                "class"       => "wpie-schedule-interval",
                                                                "default"     => [],
                                                                "description" => __( 'Run schedule after each interval', 'wp-import-export' ),
                                                                "choices"     => self::getCrons()
                                                        ]
                                                ]
                                        ],
                                        "schedule-start"    => [
                                                "order"      => 30,
                                                "label"      => __( 'Schedule Start at', 'wp-import-export' ),
                                                "sub-fields" => [
                                                        "start"         => [
                                                                "type"        => "select",
                                                                "placeholder" => __( "Choose time", 'wp-import-export' ),
                                                                "order"       => 5,
                                                                "class"       => "wpie-schedule-start",
                                                                "default"     => [ 'now' ],
                                                                "name"        => "schedule/start",
                                                                "description" => __( 'Start at', 'wp-import-export' ),
                                                                "choices"     => self::getTImeList(),
                                                                "hint"        => [
                                                                        [ "text" => __( 'Default : Current time', 'wp-import-export' ) ],
                                                                        [ "text" => __( 'Local time for start schedule', 'wp-import-export' ) ],
                                                                        [ "text" => __( 'If the specified time has already passed, the system will shift to the time for the next day', 'wp-import-export' ) ],
                                                                ]
                                                        ],
                                                        "schedule-save" => [
                                                                "type"       => "button",
                                                                "order"      => 120,
                                                                "label"      => __( 'Save Schedule', 'wp-import-export' ),
                                                                "icon-class" => "fa-solid fa-check",
                                                                "class"      => "wpie-save-schedule-btn btn-primary mt-3 btn-lg",
                                                        ]
                                                ]
                                        ]
                                ]
                        ]
                );
        }

        
        private static function getTImeList() {

                $start = strtotime( '00:00' );
                $end   = strtotime( '23:59' );

                $current = $start;

                $times = [ "now" => __( 'Now', 'wp-import-export' ) ];

                while ( $current <= $end ) {

                        $time           = Date::getCoreDate( 'H:i', $current );
                        $times[ $time ] = $time;
                        $current        = strtotime( '+30 minutes', $current );
                }

                return $times;
        }

        
        private static function getCrons() {

                $data = ScheduleBase::getSchedules();

                $schedules = [];

                foreach ( $data as $key => $schedule ) {
                        $schedules[ $key ] = isset( $schedule[ 'display' ] ) ? $schedule[ 'display' ] : "";
                }
                return $schedules;
        }
}
