<?php



namespace WpieApp\Modules\Import\Controller\File\Downloader\Base;

use WP_Error;
use Exception;
use League\Flysystem\Filesystem;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;

defined( 'WPIE__FILE__' ) || exit;


class Manager {

        
        protected static $adapter;

        
        protected static $config = [];

        
        private static $path;

        
        private static $filesystem;

        
        private static function init() {

                self::setPath( Settings::getOption( 'uploder/options/path' ) );

                try {
                        self::$filesystem = new Filesystem( self::$adapter, self::$config );
                } catch ( \Exception $e ) {
                        return new WP_Error( 'wpieError', $e->getMessage() );
                }
        }

        
        protected static function listContents() {

                $init = self::init();

                if ( is_wp_error( $init ) ) {
                        return $init;
                }

                try {
                        $allowedExt = Helper::getSupportedExt();

                        $files = [];

                        $dirs = [];

                        $listing = self::$filesystem->listContents( self::$path );

                        foreach ( $listing as $item ) {

                                $rand = Helper::randStr();

                                if ( $item->isDir() ) {
                                        $dirs[ $rand ] = $item->path();
                                        continue;
                                }

                                $file = $item->path();

                                $ext = Helper::getFileExt( basename( $file ) );

                                if ( !\in_array( $ext, $allowedExt ) ) {
                                        continue;
                                }

                                $files[ $rand ] = $item->path();
                        }

                        return [ 'files' => $files, 'folders' => $dirs, 'path' => self::$path ];
                } catch ( Exception $e ) {
                        return new WP_Error( 'wpieError', $e->getMessage() );
                }
        }

        
        protected static function setPath( $path = "" ) {

                self::$path = Helper::isNonEmptyStr( $path ) ? Helper::strTrim( $path, '/' ) . '/' : "";
        }

        
        protected static function Download() {

                $init = self::init();

                if ( is_wp_error( $init ) ) {
                        return $init;
                }

                try {
                        $fileExists = self::$filesystem->fileExists( self::$path );

                        if ( false === $fileExists ) {
                                return new WP_Error( 'wpieError', __( 'File not Exists', 'wp-import-export' ) );
                        }
                } catch ( Exception $exception ) {
                        return new WP_Error( 'wpieError', $exception->getMessage() );
                }

                try {
                        $file = self::setFile( self::$path );

                        $isDownloded =  Helper::getFilesystem()->put_contents( $file, self::$filesystem->read( self::$path ) );

                        if ( false === $isDownloded ) {
                                return new WP_Error( 'wpieError', __( 'Fail to Download File', 'wp-import-export' ) );
                        }

                        //file_put_contents
                } catch ( Exception $exception ) {
                        return new WP_Error( 'wpieError', $exception->getMessage() );
                }

                return self::$path;
        }

        
        protected static function setFile( $fileName = "" ) {

                $fileName = Helper::sanitizeFilename( basename( $fileName ) );

                Settings::set( 'file', $fileName );

                $filedir = Settings::createImportDir( 'upload' );

                if ( false === $filedir ) {
                        return new \WP_Error( 'wpie_import_error', __( 'Failed to Crate Directory', 'wp-import-export' ) );
                }

                return $filedir . DIRECTORY_SEPARATOR . $fileName;
        }
}
