<?php



namespace WpieApp\Modules\Import\Controller\File\Downloader\Ftp;

use WP_Error;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use League\Flysystem\Ftp\FtpAdapter;
use League\Flysystem\Ftp\FtpConnectionOptions;
use WpieApp\Modules\Import\Controller\File\Downloader\Base\Manager as Filesystem;

defined( 'WPIE__FILE__' ) || exit;


class Manager extends Filesystem {

	
	public static function listContents() {

		$isConnect = self::connect();
		if ( is_wp_error( $isConnect ) ) {
			return $isConnect;
		}
		return parent::listContents();
	}

	
	public static function Download() {

		$isConnect = self::connect();
		if ( is_wp_error( $isConnect ) ) {
			return $isConnect;
		}
		return parent::Download();
	}

	
	private static function connect() {

		$host = Helper::removeScheme( Settings::getOption( 'uploder/options/sever' ) );
		if ( !Helper::isNonEmptyStr( $host ) ) {
			return new WP_Error( 'wpieError', __( "FTP Server is empty", 'wp-import-export' ) );
		}

		$username = Settings::getOption( 'uploder/options/username' );
		if ( !Helper::isNonEmptyStr( $username ) ) {
			return new WP_Error( 'wpieError', __( "FTP Server Username is empty", 'wp-import-export' ) );
		}

		$password = Settings::getOption( 'uploder/options/password' );
		if ( !Helper::isNonEmptyStr( $password ) ) {
			return new WP_Error( 'wpieError', __( "FTP Server Password is empty", 'wp-import-export' ) );
		}

		$port = Helper::toInt( Settings::getOption( 'uploder/options/port' ) );

		$isSSL = Helper::toInt( Settings::getOption( 'uploder/options/is-ssl' ) ) === 1;

		parent::$adapter = new FtpAdapter(
			// Connection options
			FtpConnectionOptions::fromArray( [
				'host'		 => $host, // required
				'root'		 => '/', // required
				'username'	 => $username, // required
				'password'	 => $password, // required
				'port'		 => ($port === 0 ) ? 21 : $port,
				'ssl'		 => $isSSL,
				'timeout'	 => 300,
			] )
		);

		return true;
	}

}
