<?php



namespace WpieApp\Modules\Import\Controller\File\Downloader;

use WpieApp\Core\Admin\AutoLoader;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\File\Downloader\Url\Manager as Url;
use WpieApp\Modules\Import\Controller\File\Downloader\ExistingFile\Manager as ExistingFile;
use WpieApp\Modules\Import\Controller\File\Downloader\Ftp\Manager as Ftp;
use WpieApp\Modules\Import\Controller\File\Downloader\Sftp\Manager as Sftp;
use WpieApp\Modules\Import\Controller\File\Downloader\GoogleDrive\Manager as GoogleDrive;
use WpieApp\Modules\Import\Controller\File\Downloader\GoogleCloudStorage\Manager as GoogleCloudStorage;
use WpieApp\Modules\Import\Controller\File\Downloader\Dropbox\Manager as Dropbox;

defined( 'WPIE__FILE__' ) || exit;


class Manager {

        
        private static $options = [];

        
        public static function init( $operation = "", $options = [] ) {

                self::$options = $options;

                if ( "url" !== Settings::getOption( 'uploder/method' ) ) {
                        AutoLoader::loadFlysystem();
                }

                if ( "connect" === $operation ) {
                        return self::connect();
                } elseif ( "update-path" === $operation ) {
                        return self::updatePath();
                } elseif ( "download" === $operation ) {
                        return self::Download();
                }
        }

        
        private static function connect() {

                Settings::setOptions( Helper::_post( "settings" ) );

                return self::updatePath( false );
        }

        
        private static function updatePath( $setPath = true ) {

                if ( $setPath ) {
                        Settings::setOption( 'uploder/options/path', isset( self::$options[ 'path' ] ) ? self::$options[ 'path' ] : "" );
                }

                $method = Settings::getOption( 'uploder/method' );

                if ( "ftp" === trim( $method ) ) {
                        return Ftp::listContents();
                } elseif ( "sftp" === trim( $method ) ) {
                        return Sftp::listContents();
                } elseif ( "google-drive" === trim( $method ) ) {
                        return GoogleDrive::listContents();
                } elseif ( "google-cloud-storage" === trim( $method ) ) {
                        return GoogleCloudStorage::listContents();
                } elseif ( "dropbox" === trim( $method ) ) {
                        return Dropbox::listContents();
                }
        }

        
        private static function Download() {

                Settings::setOption( 'uploder/options/path', isset( self::$options[ 'path' ] ) ? self::$options[ 'path' ] : "" );

                $method = Settings::getOption( 'uploder/method' );

                if ( "url" === trim( $method ) ) {
                        Settings::setOption( 'uploder/options/url', isset( self::$options[ 'url' ] ) ? self::$options[ 'url' ] : "" );
                        return Url::Download();
                } elseif ( "existing-file" === trim( $method ) ) {
                        return ExistingFile::Download();
                } elseif ( "ftp" === trim( $method ) ) {
                        return Ftp::Download();
                } elseif ( "sftp" === trim( $method ) ) {
                        return Sftp::Download();
                } elseif ( "google-drive" === trim( $method ) ) {
                        return GoogleDrive::Download();
                } elseif ( "google-cloud-storage" === trim( $method ) ) {
                        return GoogleCloudStorage::Download();
                } elseif ( "dropbox" === trim( $method ) ) {
                        return Dropbox::Download();
                }
        }
}
