<?php



namespace WpieApp\Modules\Import\Controller\Items\Comment\Engines;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Comment\DataCenter;
use WpieApp\Modules\Import\Controller\Items\Post\Search;
use WpieApp\Modules\Import\Controller\Items\Comment\Fields\Post\Options;

defined( 'WPIE__FILE__' ) || exit;


class Post {

        
        private static $cache = [];

        
        protected static $postTypes = [];

        
        public static function get() {

                $key = DataCenter::getKey();

                if ( isset( self::$cache[ $key ] ) ) {
                        return self::$cache[ $key ];
                }

                $data = [];

                if ( DataCenter::canUpdate( "post/post_data" ) ) {
                        $data[ "comment_post_ID" ] = static::getPost( DataCenter::get( "post/title/data" ), DataCenter::get( "post/slug/data" ) );
                }

                self::$cache = [ $key => $data ];

                return $data;
        }

        
        public static function getPost( $title = '', $slug = '' ) {

                $id = self::getPostId( $title, $slug );

                if ( $id > 0 ) {
                        return $id;
                }

                return self::getPostId( $title, $slug, 'AND' );
        }

        
        public static function getPostId( $title = '', $slug = '', $relation = 'OR' ) {

                if ( !Helper::isNonEmptyStr( $title ) && !Helper::isNonEmptyStr( $slug ) ) {
                        return 0;
                }
                $arg = [];

                if ( Helper::isNonEmptyStr( $title ) ) {
                        $arg[] = [ "key" => "title", "value" => $title, 'relation' => $relation ];
                }
                if ( Helper::isNonEmptyStr( $slug ) ) {
                        $arg[] = [ "key" => "name", "value" => $slug, 'relation' => $relation ];
                }

                $query = [ [ "args" => $arg ] ];

                $types = static::getPostType();

                if ( false !== $types ) {
                        $query[] = [ "args" => [ [ "key" => 'type', "value" => $types ] ] ];
                }

                return Search::getId( $query );
        }

        
        private static function getPostType() {

                static::setPostTypes();

                $types = DataCenter::get( "post/post_type/data" );

                if ( !Helper::isNonEmptyArray( $types ) ) {
                        return static::$postTypes;
                }

                return array_intersect( $types, static::$postTypes );
        }

        
        private static function setPostTypes() {

                if ( Helper::isNonEmptyArray( static::$postTypes ) ) {
                        return;
                }

                $supportedTypes = Options::getPostTypes();

                static::$postTypes = Helper::isNonEmptyArray( $supportedTypes ) ? array_keys( $supportedTypes ) : [];
        }

}
