<?php



namespace WpieApp\Modules\Import\Controller\Items\Post;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Base\Engine as BaseEngine;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Standard;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Author;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Other;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Taxonomy;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Meta;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Image;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Attachment;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Engine extends BaseEngine {

        
        protected static function preStart() {
                Revision::manage();
        }

        
        public static function import() {

                \do_action( "Wpie/Import/Post/Engine/Start" );

                if ( !static::insertPost() ) {
                        return false;
                }

                static::afterAdd();

                static::updatePost();

                \do_action( "Wpie/Import/Post/Engine/End" );

                return true;
        }

        
        protected static function afterAdd() {

                \do_action( "Wpie/Import/Post/Engine/Add/After" );

                parent::afterAdd();
        }

        
        protected static function preparePost() {

                $standard = Standard::get();
                $author   = Author::get();
                $others   = Other::get();
                $data     = array_merge( $standard, $author, $others );

                if ( DataCenter::isNewItem() ) {

                        $data[ 'post_type' ] = Settings::getContentType();
                }

                return $data;
        }

        
        protected static function setItem( $id = 0 ) {

                DataCenter::setId( $id );

                DataCenter::setItem( \get_post( $id ) );
        }

        
        protected static function updatePost() {

                Standard::relinkContent();

                Other::setProp();

                Taxonomy::import();

                static::updateMeta();

                Image::import();

//                Attachment::import();
        }

        
        protected static function updateMeta() {

                Meta::import();
        }

        
        protected static function insertPost() {

                $data = \apply_filters( "Wpie/Import/Post/Import/Before", static::preparePost(), Settings::getContentType() );

                $id = ( DataCenter::isNewItem() ? self::insert( $data ) : self::update( $data ));

                if ( false === $id ) {
                        return false;
                }

                if ( \is_wp_error( $id ) ) {

                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $id->get_error_message() );

                        return false;
                }

                if ( \absint( $id ) === 0 ) {

                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( "something wrong, ID = 0 was generated.", 'wp-import-export' ) );

                        return false;
                }

                static::setItem( $id );

                return true;
        }

        
        protected static function insert( $data = [] ) {

                if ( isset( $data[ 'ID' ] ) ) {
                        unset( $data[ 'ID' ] );
                }
                if ( !Helper::isNonEmptyArray( $data ) ) {
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> :" . __( "Content, title, and excerpt are empty.", 'wp-import-export' ) );
                        return false;
                }

                return \wp_insert_post( $data, true );
        }

        
        protected static function update( $data = [] ) {

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return DataCenter::getId();
                }

                $data[ 'ID' ] = DataCenter::getId();

                $result = \wp_update_post( $data, true );

                if ( \is_wp_error( $result ) ) {

                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $result->get_error_message() );
                }

                return DataCenter::getId();
        }

        
        public static function searchDuplicates() {

                $searchMethod = DataCenter::get( "search/method" );

                $postType = Settings::get( 'content_type' );

                $id = 0;

                switch ( $searchMethod ) {

                        case "meta":
                                $metaKey   = DataCenter::get( "search/meta/key" );
                                $metaValue = DataCenter::get( "search/meta/value" );

                                if ( Helper::isNonEmptyStr( $metaKey ) && Helper::isNonEmptyStr( $metaValue ) ) {
                                        $id = Search::getPostIdByMeta( $metaKey, $metaValue, $postType );
                                }
                                break;

                        default:
                                $id = AutoSearch::get( $searchMethod, [ 'postType' => $postType ] );
                                break;
                }

                return $id;
        }
}
