<?php



namespace WpieApp\Modules\Import\Controller\Items\Post\ExistingItemsFields;

use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Base\ExistingItemsFields\Standard as Base;

defined( 'WPIE__FILE__' ) || exit;


class Standard extends Base {

        
        public static function getFields() {

                $postType = Settings::getContentLabel();

                return [
                        "type"        => "radio",
                        "order"       => 10,
                        "name"        => "search/method",
                        "class"       => "existing-item-serach-by",
                        "default"     => "auto",
                        "description" => __( 'Search for items on your site by...', 'wp-import-export' ),
                        "choices"     => [
                                "auto"    => "Auto Detect",
                                "title"   => "Title",
                                "content" => "Content",
                                "slug"    => "Slug",
                                "id"      => $postType . " ID",
                                "meta"    => "Meta"
                        ],
                        "hints"       => [
                                "auto"    => __( "Detect items automatically by analyzing mapping and file data", 'wp-import-export' ),
                                /* translators: %s: content type */
                                "title"   => sprintf( __( "Search %s by Title", 'wp-import-export' ), $postType ),
                                /* translators: %s: content type */
                                "content" => sprintf( __( "Search %s by Content", 'wp-import-export' ), $postType ),
                                /* translators: %s: content type */
                                "slug"    => sprintf( __( "Search %s by Slug", 'wp-import-export' ), $postType ),
                                /* translators: %s: content type */
                                "id"      => sprintf( __( "Search %s by ID", 'wp-import-export' ), $postType ),
                                /* translators: %s: content type */
                                "meta"    => sprintf( __( "Search %s by Meta", 'wp-import-export' ), $postType ),
                        ],
                        "fields"      => [
                                "title"   => [
                                        "post_title" => [
                                                "order"      => 5,
                                                "sub-fields" => [
                                                        "title" => [
                                                                "type"        => "textarea",
                                                                "order"       => 10,
                                                                "name"        => "fields/search/title",
                                                                /* translators: %s: content type */
                                                                "placeholder" => sprintf( __( "Enter %s title here...", 'wp-import-export' ), $postType ),
                                                                "description" => __( 'Leave empty for auto get title value from Field Mapping steps', 'wp-import-export' ),
                                                        ]
                                                ]
                                        ]
                                ],
                                "content" => [
                                        "post_content" => [
                                                "order"      => 5,
                                                "sub-fields" => [
                                                        "content" => [
                                                                "type"        => "textarea",
                                                                "order"       => 10,
                                                                "name"        => "fields/search/content",
                                                                /* translators: %s: content type */
                                                                "placeholder" => sprintf( __( "Enter %s content here...", 'wp-import-export' ), $postType ),
                                                                "description" => __( 'Leave empty for auto get content value from Field Mapping steps', 'wp-import-export' ),
                                                        ]
                                                ]
                                        ]
                                ],
                                "slug"    => [
                                        "post_slug" => [
                                                "order"      => 5,
                                                "sub-fields" => [
                                                        "slug" => [
                                                                "type"        => "textarea",
                                                                "order"       => 20,
                                                                "name"        => "fields/search/slug",
                                                                /* translators: %s: content type */
                                                                "placeholder" => sprintf( __( "Enter %s slug here...", 'wp-import-export' ), $postType ),
                                                                "description" => __( 'Leave empty for auto get slug value from Field Mapping steps', 'wp-import-export' ),
                                                        ]
                                                ]
                                        ]
                                ],
                                "id"      => [
                                        "post_id" => [
                                                "order"      => 5,
                                                "sub-fields" => [
                                                        "as-specified" => [
                                                                "type"        => "textarea",
                                                                "order"       => 20,
                                                                "name"        => "fields/search/id",
                                                                /* translators: %s: content type */
                                                                "placeholder" => sprintf( __( "Enter %s id here...", 'wp-import-export' ), $postType ),
                                                        //  "description" => __( 'Please Fill id field below', 'wp-import-export' ),
                                                        ]
                                                ]
                                        ]
                                ],
                                "meta"    => [
                                        "post_meta" => [
                                                "order"      => 5,
                                                "sub-fields" => [
                                                        "meta-key" => [
                                                                "type"        => "text",
                                                                "order"       => 10,
                                                                "name"        => "fields/search/meta/key",
                                                                "description" => __( 'Please Fill Meta Key field below', 'wp-import-export' ),
                                                        ],
                                                        "meta-val" => [
                                                                "type"        => "text",
                                                                "order"       => 20,
                                                                "name"        => "fields/search/meta/value",
                                                                "description" => __( 'Please Fill Meta Value field below', 'wp-import-export' ),
                                                        ]
                                                ]
                                        ]
                                ]
                        ]
                ];
        }

        
        public static function getNotes() {

                
                return \array_merge( parent::getNotes(),
                        [
                                [
                                        "type"       => "danger",
                                        "icon-class" => "fa-solid fa-triangle-exclamation",
                                        "class"      => 'me-3',
                                        "text"       => __( 'If fields like titles, slugs, or content are repeated and non-unique, skip auto-detect', 'wp-import-export' ),
                                ]
                        ]
                );
        }
}
