<?php



namespace WpieApp\Modules\Import\Controller\Items\Post\Fields\Taxonomies;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;

defined( 'WPIE__FILE__' ) || exit;


class Taxonomy {

        
        public static function getBlocks() {

                $taxonomies = static::getTaxonomies();

                if ( !Helper::isNonEmptyArray( $taxonomies ) ) {
                        return [];
                }


                $excludes = static::getExcludePostTaxonomies();

                $fields = [];

                $order = 10;

                foreach ( $taxonomies as $key => $taxonomy ) {

                        if ( is_array( $excludes ) && in_array( $key, $excludes ) ) {
                                continue;
                        }

                        $label = isset( $taxonomy->label ) ? $taxonomy->label : $key;

                        $taxonomySlug = "taxonomy/" . $key;

                        $fields[ $taxonomySlug ] = [
                                "title"     => $label,
                                "sub-title" => $key,
                                "desc"      => $key,
                                "order"     => $order,
                                "uid"       => Helper::randStr( "wpie-field-" ),
                                "isActive"  => $order === 10,
                                "fields"    => [
                                        "item-category"           => [
                                                "order"      => 10,
                                                "label"      => $label,
                                                "sub-fields" => [
                                                        "item-category" => [
                                                                /* translators: %s: term taxonomy*/
                                                                "description" => sprintf( __( 'Inserted new %s term data if not exist in your site. Assign if exist.', 'wp-import-export' ), $label ),
                                                                "name"        => "fields/" . $taxonomySlug . "/data",
                                                                "type"        => "textarea",
                                                                "hint"        => [
                                                                        [ 'text' => __( 'Optional', 'wp-import-export' ) ],
                                                                ]
                                                        ]
                                                ],
                                        ],
                                        "item-category-separator" => [
                                                "order"      => 20,
                                                /* translators: %s: term taxonomy*/
                                                "label"      => sprintf( __( 'Manage Multiple %s ', 'wp-import-export' ), $label ),
                                                "sub-fields" => [
                                                        "item-category-separator" => [
                                                                /* translators: %s: term taxonomy*/
                                                                "description" => sprintf( __( 'Separate Multiple %s via symbol (i.e. Movies, Games, Videos)', 'wp-import-export' ), $label ),
                                                                'col-class'   => "cols",
                                                                "name"        => "fields/" . $taxonomySlug . "/separator",
                                                                "type"        => "text",
                                                                "value"       => ",",
                                                                "hint"        => [
                                                                        [ 'text' => __( 'Optional', 'wp-import-export' ) ],
                                                                        [ 'text' => __( 'Default : ,(Comma)', 'wp-import-export' ) ]
                                                                ]
                                                        ],
                                                ],
                                        ]
                                ]
                        ];

                        if ( $taxonomy->hierarchical ) {
                                $fields[ $taxonomySlug ][ "fields" ][ "item-category-hierarchy-separator" ] = [
                                        "order"      => 30,
                                        /* translators: %s: term taxonomy*/
                                        "label"      => sprintf( __( 'Manage %s hierarchy', 'wp-import-export' ), $label ),
                                        "sub-fields" => [
                                                "item-category-hierarchy-separator" => [
                                                        /* translators: %s: term taxonomy*/
                                                        "description" => sprintf( __( 'Separate Multiple %s hierarchy (parent/child) via symbol (i.e. Clothing > Men > TShirts)', 'wp-import-export' ), $label ),
                                                        'col-class'   => "cols",
                                                        "name"        => "fields/" . $taxonomySlug . "/hierarchy-separator",
                                                        "type"        => "text",
                                                        "value"       => ">",
                                                        "hint"        => [
                                                                [ 'text' => __( 'Optional', 'wp-import-export' ) ],
                                                                [ 'text' => __( 'Default : >', 'wp-import-export' ) ]
                                                        ]
                                                ],
                                        ],
                                ];
                        }

                        $order += 10;
                }

                return $fields;
        }

        
        protected static function getTaxonomies() {

                return \get_object_taxonomies( [ Settings::getContentType() ], "object" );
        }

        
        protected static function getExcludePostTaxonomies() {

                $types = [ 'post_format' ];

                
                return apply_filters( 'Wpie/Import/Post/Taxonomy/Excludes', $types );
        }

}
